#include <SoftwareSerial.h>

#define SENSORPIN	(0)
#define WAKEPIN		(8)
#define SENSORINPUTPIN	(13)

const char szUUIDChara1[] = "022EA09A348A11E8B4670ED5F89F718B";

SoftwareSerial g_rn4020( 6, 7 );

// 測定と送信フラグ
volatile boolean g_bReadAndSend = false;

void setup()
{
	// WAKEピンのセットアップ
	pinMode( WAKEPIN, OUTPUT );
	digitalWrite( WAKEPIN, HIGH );

	// センサーインプットピンのセットアップ
	pinMode( SENSORINPUTPIN, OUTPUT );
	digitalWrite( SENSORINPUTPIN, LOW );

	// RN4020の起動待ちウェイト
	delay( 1000 );	// 1秒

	// ボーレートを指定して通信開始
	g_rn4020.begin( 115200 );

	// RN4020をスリープさせる
	digitalWrite( WAKEPIN, LOW );

	// アプリからのBLE通信接続時の割り込み処理の設定
	attachInterrupt( 0, DetectedConnection, HIGH );	// INT0端子(２番ピン)の立ち上がりで割り込み発生。
}

void loop()
{
	// 測定と送信フラグが立っているときだけ処理する
	if( g_bReadAndSend )
	{
		// 測定と送信フラグを倒す
		g_bReadAndSend = false;

		// 測定と送信
		ReadAndSend();

		// アプリからのBLE通信接続時の割り込み処理の設定
		attachInterrupt( 0, DetectedConnection, HIGH );	// INT0端子(２番ピン)の立ち上がりで割り込み発生。
	}
}

// 測定と送信
void ReadAndSend()
{
	// RN4020をスリープから復帰させる
	digitalWrite( WAKEPIN, HIGH );

	// センサーに通電
	digitalWrite( SENSORINPUTPIN, HIGH );

	// 測定
	int iValue = analogRead( SENSORPIN );

	// センサーの通電の解除
	digitalWrite( SENSORINPUTPIN, LOW );

	// 測定値のBLEモジュールへの書き込み
	char szCommand[1024] = "";	// 送信コマンド
	sprintf( szCommand, "SUW,%s,%04X", szUUIDChara1, iValue );	// コマンド作成
	g_rn4020.println( szCommand );	// コマンド送信

	// RN4020をスリープさせる
	digitalWrite( WAKEPIN, LOW );
}

// 外部割り込みの結果呼び出される関数
void DetectedConnection()
{
	// 外部割り込み条件の設定を解除
	detachInterrupt(0);

	// 測定と送信フラグを立てる
	g_bReadAndSend = true;
}
